EXPORTS
	?BusRespondSrp@RUsb@@QAEHXZ @ 1 NONAME ; int RUsb::BusRespondSrp(void)
	?HostEventNotificationCancel@RUsb@@QAEXXZ @ 2 NONAME ; void RUsb::HostEventNotificationCancel(void)
	?DeviceStateNotificationCancel@RUsb@@QAEXXZ @ 3 NONAME ; void RUsb::DeviceStateNotificationCancel(void)
	?CancelInterest@RUsb@@QAEHW4TUsbReqType@1@@Z @ 4 NONAME ; int RUsb::CancelInterest(enum RUsb::TUsbReqType)
	?__DbgMarkEnd@RUsb@@QAEHH@Z @ 5 NONAME ; int RUsb::__DbgMarkEnd(int)
	?StateNotification@RUsb@@QAEXIAAW4TUsbDeviceState@@AAVTRequestStatus@@@Z @ 6 NONAME ; void RUsb::StateNotification(unsigned int, enum TUsbDeviceState &, class TRequestStatus &)
	?BusRequest@RUsb@@QAEHXZ @ 7 NONAME ; int RUsb::BusRequest(void)
	?panic@@YAXXZ @ 8 NONAME ; void panic(void)
	?StateNotificationCancel@RUsb@@QAEXXZ @ 9 NONAME ; void RUsb::StateNotificationCancel(void)
	?Connect@RUsb@@QAEHXZ @ 10 NONAME ; int RUsb::Connect(void)
	?GetCurrentState@RUsb@@QAEHAAW4TUsbServiceState@@@Z @ 11 NONAME ; int RUsb::GetCurrentState(enum TUsbServiceState &)
	?Version@RUsb@@QBE?AVTVersion@@XZ @ 12 NONAME ; class TVersion RUsb::Version(void) const
	??0RUsb@@QAE@XZ @ 13 NONAME ; RUsb::RUsb(void)
	?RequestSession@RUsb@@QAEHXZ @ 14 NONAME ; int RUsb::RequestSession(void)
	?TryStart@RUsb@@QAEXHAAVTRequestStatus@@@Z @ 15 NONAME ; void RUsb::TryStart(int, class TRequestStatus &)
	?GetSupportedClasses@RUsb@@QAEHHAAV?$RArray@VTUid@@@@@Z @ 16 NONAME ; int RUsb::GetSupportedClasses(int, class RArray<class TUid> &)
	?DeviceStateNotification@RUsb@@QAEXIAAW4TUsbDeviceState@@AAVTRequestStatus@@@Z @ 17 NONAME ; void RUsb::DeviceStateNotification(unsigned int, enum TUsbDeviceState &, class TRequestStatus &)
	?TryStop@RUsb@@QAEXAAVTRequestStatus@@@Z @ 18 NONAME ; void RUsb::TryStop(class TRequestStatus &)
	?__DbgAlloc@RUsb@@QAEHXZ @ 19 NONAME ; int RUsb::__DbgAlloc(void)
	?DisableFunctionDriverLoading@RUsb@@QAEXXZ @ 20 NONAME ; void RUsb::DisableFunctionDriverLoading(void)
	?ServiceStateNotificationCancel@RUsb@@QAEXXZ @ 21 NONAME ; void RUsb::ServiceStateNotificationCancel(void)
	?Stop@RUsb@@QAEXAAVTRequestStatus@@@Z @ 22 NONAME ; void RUsb::Stop(class TRequestStatus &)
	?ServiceStateNotification@RUsb@@QAEXAAW4TUsbServiceState@@AAVTRequestStatus@@@Z @ 23 NONAME ; void RUsb::ServiceStateNotification(enum TUsbServiceState &, class TRequestStatus &)
	??1RUsb@@QAE@XZ @ 24 NONAME ; RUsb::~RUsb(void)
	?StartCancel@RUsb@@QAEXXZ @ 25 NONAME ; void RUsb::StartCancel(void)
	?EnableFunctionDriverLoading@RUsb@@QAEHXZ @ 26 NONAME ; int RUsb::EnableFunctionDriverLoading(void)
	?HostEventNotification@RUsb@@QAEXAAVTRequestStatus@@AAVTDeviceEventInformation@@@Z @ 27 NONAME ; void RUsb::HostEventNotification(class TRequestStatus &, class TDeviceEventInformation &)
	?ClassSupported@RUsb@@QAEHHVTUid@@AAH@Z @ 28 NONAME ; int RUsb::ClassSupported(int, class TUid, int &)
	?__DbgCheckHeap@RUsb@@QAEHH@Z @ 29 NONAME ; int RUsb::__DbgCheckHeap(int)
	?GetPersonalityProperty@RUsb@@QAEHHAAK@Z @ 30 NONAME ; int RUsb::GetPersonalityProperty(int, unsigned long &)
	?Stop@RUsb@@QAEXXZ @ 31 NONAME ; void RUsb::Stop(void)
	?GetDetailedDescription@RUsb@@QAEHHAAPAVHBufC16@@@Z @ 32 NONAME ; int RUsb::GetDetailedDescription(int, class HBufC16 * &)
	?GetServiceState@RUsb@@QAEHAAW4TUsbServiceState@@@Z @ 33 NONAME ; int RUsb::GetServiceState(enum TUsbServiceState &)
	?MessageNotificationCancel@RUsb@@QAEXXZ @ 34 NONAME ; void RUsb::MessageNotificationCancel(void)
	?BusDrop@RUsb@@QAEHXZ @ 35 NONAME ; int RUsb::BusDrop(void)
	?GetPersonalityIds@RUsb@@QAEHAAV?$RArray@H@@@Z @ 36 NONAME ; int RUsb::GetPersonalityIds(class RArray<int> &)
	?GetSupportedLanguages@RUsb@@QAEHIAAV?$RArray@I@@@Z @ 37 NONAME ; int RUsb::GetSupportedLanguages(unsigned int, class RArray<unsigned int> &)
	?SetCtlSessionMode@RUsb@@QAEHH@Z @ 38 NONAME ; int RUsb::SetCtlSessionMode(int)
	?StopCancel@RUsb@@QAEXXZ @ 39 NONAME ; void RUsb::StopCancel(void)
	?Start@RUsb@@QAEXAAVTRequestStatus@@@Z @ 40 NONAME ; void RUsb::Start(class TRequestStatus &)
	?__DbgFailNext@RUsb@@QAEHH@Z @ 41 NONAME ; int RUsb::__DbgFailNext(int)
	?GetManufacturerStringDescriptor@RUsb@@QAEHIIAAV?$TBuf@$0IA@@@@Z @ 42 NONAME ; int RUsb::GetManufacturerStringDescriptor(unsigned int, unsigned int, class TBuf<128> &)
	?MessageNotification@RUsb@@QAEXAAVTRequestStatus@@AAH@Z @ 43 NONAME ; void RUsb::MessageNotification(class TRequestStatus &, int &)
	?BusClearError@RUsb@@QAEHXZ @ 44 NONAME ; int RUsb::BusClearError(void)
	?GetProductStringDescriptor@RUsb@@QAEHIIAAV?$TBuf@$0IA@@@@Z @ 45 NONAME ; int RUsb::GetProductStringDescriptor(unsigned int, unsigned int, class TBuf<128> &)
	?GetDescription@RUsb@@QAEHHAAPAVHBufC16@@@Z @ 46 NONAME ; int RUsb::GetDescription(int, class HBufC16 * &)
	?__DbgMarkHeap@RUsb@@QAEHXZ @ 47 NONAME ; int RUsb::__DbgMarkHeap(void)
	?GetDeviceState@RUsb@@QAEHAAW4TUsbDeviceState@@@Z @ 48 NONAME ; int RUsb::GetDeviceState(enum TUsbDeviceState &)
	?GetCurrentPersonalityId@RUsb@@QAEHAAH@Z @ 49 NONAME ; int RUsb::GetCurrentPersonalityId(int &)
	?GetOtgDescriptor@RUsb@@QAEHIAAVTOtgDescriptor@@@Z @ 50 NONAME ; int RUsb::GetOtgDescriptor(unsigned int, class TOtgDescriptor &)

